program gsas2hkl_weight
use reflection_module
use write_out_pattern
implicit none

integer, parameter :: maxpts=15000   ! max data points
integer, parameter :: maxrefs=10000  ! max reflections

integer, parameter :: max_profile_points = 1000  ! max profile values that can
                                                ! be associated with one Bragg peak
                                                
! How many off diagonal element should be saved in the .hkl_weight file.
integer :: number_of_off_diagonal_weight_elements = 14 


integer h(maxrefs),k(maxrefs),l(maxrefs),nrefs,npts
real    Iout(maxrefs),x_bragg(maxrefs),fwhm(maxrefs)
real    lor(maxrefs), x_obs(maxpts),y_obs(maxpts)

type(data_container) :: my_data
type(reflections) :: my_refs

integer :: totrefs, loop

double precision :: scale  ! scale factor between GSAS intensities and the y_obs
double precision :: gof_value = 5.0  ! GSAS goodness-of-fit value 

! get stuff from gsas output

call extsym_to_gsas(maxpts,maxrefs,nrefs,h,k,l,Iout, &
x_bragg,fwhm,lor,npts,x_obs,y_obs)


! make a data_container object

my_data = make_data_container(npts,x_obs,y_obs)


! The number of off diagonal weight elements must be less than nrefs

if (number_of_off_diagonal_weight_elements >= nrefs) then
  number_of_off_diagonal_weight_elements = nrefs - 1
end if


! make a reflections object

my_refs = make_reflections(nrefs,h,k,l,Iout,x_bragg,fwhm,lor,minval(x_obs(1:npts)),maxval(x_obs(1:npts)), &
  max_profile_points, number_of_off_diagonal_weight_elements)


! calculate the weight matrix elements

call cal_weight_matrix(my_refs, my_data)


! for debugging write out calculated pattern

scale = cal_pattern(my_refs, my_data, 'calculated_pattern.txt')


! write out .hkl_weight file

call write_out_hkl_weight_file('somename.hkl_weight', my_refs, scale)


! run ExtSym

call run_extsym('somename.hkl_weight', gof_value)


      call open_write(10,'testout','.hkl')
      write(10,*) nrefs
      totrefs=nrefs+1
      do loop=1,nrefs
      write(10,1111) totrefs-loop,h(loop),k(loop),l(loop),Iout(loop), &
                 x_bragg(loop), &
                 fwhm(loop),lor(loop)

1111  format(i5,3(i3,1x),4(e10.5,1x))
      enddo
      close(10)

      call open_write(10,'testout','.bragg')
      write(10,*) npts

      do loop=1,npts
      write(10,*) x_obs(loop),y_obs(loop)
      enddo
      close(10)


end
